==> djangoldp_energiepartagee-2.0.29.tar.gz: djangoldp_energiepartagee-2.0.29/djangoldp_energiepartagee/models/production_site.py <==
from django.db import models
from django.utils.translation import gettext_lazy as _
from djangoldp.models import Model
from djangoldp.permissions import InheritPermissions

from djangoldp_energiepartagee.models.citizen_project import CitizenProject
from djangoldp_energiepartagee.models.region import Region
from djangoldp_energiepartagee.permissions import EPRegionalAdminPermission


class ProductionSite(Model):
    citizen_project = models.ForeignKey(
        CitizenProject,
        blank=True,
        null=True,
        on_delete=models.CASCADE,
        verbose_name="Projet citoyen",
        related_name="production_sites",
    )
    name = models.CharField(max_length=250, blank=True, null=True, verbose_name="Name")
    description = models.TextField(blank=True, null=True, verbose_name="Description")
    # FIXME: Should be a property of produced energies
    reference_unit = models.TextField(
        blank=True, null=True, verbose_name="Unité de référence"
    )
    # FIXME: Should be a choice I think
    progress_status = models.CharField(
        max_length=248, blank=True, null=True, verbose_name="Progress status"
    )
    total_development_budget = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="Budget total de développement",
    )
    total_investment_budget = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="Budget total d'investissement",
    )
    yearly_turnover = models.CharField(
        max_length=50, blank=True, null=True, verbose_name="Chiffre d'affaire annuel"
    )
    address = models.CharField(
        max_length=250, blank=True, null=True, verbose_name="Adresse"
    )
    postcode = models.CharField(
        max_length=20, blank=True, null=True, verbose_name="Code Postal"
    )
    city = models.CharField(max_length=250, blank=True, null=True, verbose_name="Ville")
    department = models.CharField(
        max_length=50, blank=True, null=True, verbose_name="Département"
    )
    region = models.ForeignKey(
        Region,
        max_length=50,
        blank=True,
        null=True,
        on_delete=models.SET_NULL,
        verbose_name="Région",
        related_name="production_sites",
    )
    lat = models.DecimalField(
        max_digits=30,
        decimal_places=25,
        blank=True,
        null=True,
        verbose_name="Lattitude",
    )
    lng = models.DecimalField(
        max_digits=30,
        decimal_places=25,
        blank=True,
        null=True,
        verbose_name="Longitude",
    )
    expected_commissionning_year = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="Année de mise en service prévue",
    )
    effective_commissionning_year = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="Année de mise en service effective",
    )
    picture = models.CharField(
        max_length=250, blank=True, null=True, verbose_name="Photo"
    )
    investment_capacity_ratio = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="Ratio investissement par puissance €/kW",
    )
    grants_earned_amount = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="Montant des subventions reçues pour le Site de production (en €)",
    )
    production_tracking_url = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="URL monitoring du site de production",
    )
    visible = models.BooleanField(
        blank=True, null=True, verbose_name="Visible sur la carte", default=False
    )

    class Meta(Model.Meta):
        ordering = ["pk"]
        permission_classes = [InheritPermissions | EPRegionalAdminPermission]
        inherit_permissions = ["citizen_project"]
        rdf_type = "energiepartagee:production_site"
        nested_fields = [
            "citizen_project",
            "partner_links",
            "energy_productions",
            "earned_distinctions",
        ]
        serializer_fields = [
            "name",
            "visible",
            "description",
            "reference_unit",
            "progress_status",
            "total_development_budget",
            "total_investment_budget",
            "yearly_turnover",
            "address",
            "postcode",
            "city",
            "department",
            "region",
            "lat",
            "lng",
            "expected_commissionning_year",
            "effective_commissionning_year",
            "picture",
            "investment_capacity_ratio",
            "grants_earned_amount",
            "production_tracking_url",
            "partner_links",
            "energy_productions",
            "earned_distinctions",
            "citizen_project",
        ]
        verbose_name = _("Site de production")
        verbose_name_plural = _("Sites de productions")
        depth = 0

    def __str__(self):
        if self.name:
            return self.name
        else:
            return self.urlid

==> djangoldp_energiepartagee-2.0.52.tar.gz: djangoldp_energiepartagee-2.0.52/djangoldp_energiepartagee/models/production_site.py <==
from django.db import models
from django.utils.translation import gettext_lazy as _
from djangoldp.models import Model
from djangoldp.permissions import InheritPermissions

from djangoldp_energiepartagee.models import energy_production
from djangoldp_energiepartagee.models.citizen_project import CitizenProject
from djangoldp_energiepartagee.models.region import Region
from djangoldp_energiepartagee.permissions import EPRegionalAdminPermission


class ProductionSite(Model):
    citizen_project = models.ForeignKey(
        CitizenProject,
        blank=True,
        null=True,
        on_delete=models.CASCADE,
        verbose_name="Projet citoyen",
        related_name="production_sites",
    )
    name = models.CharField(max_length=250, blank=True, null=True, verbose_name="Name")
    description = models.TextField(blank=True, null=True, verbose_name="Description")
    # FIXME: Should be a property of produced energies
    reference_unit = models.TextField(
        blank=True, null=True, verbose_name="Unité de référence"
    )
    # FIXME: Should be a choice I think
    progress_status = models.CharField(
        max_length=248, blank=True, null=True, verbose_name="Progress status"
    )
    total_development_budget = models.DecimalField(
        max_digits=50,
        decimal_places=2,
        blank=True,
        null=True,
        verbose_name="Budget total de développement",
    )
    total_investment_budget = models.DecimalField(
        max_digits=50,
        decimal_places=2,
        blank=True,
        null=True,
        verbose_name="Budget total d'investissement",
    )
    yearly_turnover = models.CharField(
        max_length=50, blank=True, null=True, verbose_name="Chiffre d'affaire annuel"
    )
    address = models.CharField(
        max_length=250, blank=True, null=True, verbose_name="Adresse"
    )
    postcode = models.CharField(
        max_length=20, blank=True, null=True, verbose_name="Code Postal"
    )
    city = models.CharField(max_length=250, blank=True, null=True, verbose_name="Ville")
    department = models.CharField(
        max_length=50, blank=True, null=True, verbose_name="Département"
    )
    region = models.ForeignKey(
        Region,
        max_length=50,
        blank=True,
        null=True,
        on_delete=models.SET_NULL,
        verbose_name="Région",
        related_name="production_sites",
    )
    lat = models.DecimalField(
        max_digits=30,
        decimal_places=25,
        blank=True,
        null=True,
        verbose_name="Lattitude",
    )
    lng = models.DecimalField(
        max_digits=30,
        decimal_places=25,
        blank=True,
        null=True,
        verbose_name="Longitude",
    )
    expected_commissionning_year = models.DecimalField(
        max_digits=5,
        decimal_places=0,
        blank=True,
        null=True,
        verbose_name="Année de mise en service prévue",
    )
    effective_commissionning_year = models.DecimalField(
        max_digits=5,
        decimal_places=0,
        blank=True,
        null=True,
        verbose_name="Année de mise en service effective",
    )
    picture = models.CharField(
        max_length=250, blank=True, null=True, verbose_name="Photo"
    )
    investment_capacity_ratio = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="Ratio investissement par puissance €/kW",
    )
    grants_earned_amount = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="Montant des subventions reçues pour le Site de production (en €)",
    )
    production_tracking_url = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name="URL monitoring du site de production",
    )
    visible = models.BooleanField(
        blank=True, null=True, verbose_name="Visible sur la carte", default=False
    )

    @property
    def technology_used(self):
        technologies_used = self.technologies_used
        if technologies_used and len(technologies_used) > 1:
            return "multi"
        else:
            return technologies_used.pop() if technologies_used else "unknown"

    @property
    def energy_type(self):
        energy_produced = self.energies_produced
        if energy_produced and len(energy_produced) > 1:
            return "multi"
        return energy_produced.pop() if energy_produced else "unknown"

    @property
    def technologies_used(self):
        energy_productions = self.energy_productions.filter(technology_used__isnull=False)
        if energy_productions:
            return (
                set(
                    energy_productions
                    .values_list("technology_used", flat=True)
                    .distinct()
                )
                if self.visible
                else None
            )
        return None

    @property
    def energies_produced(self):
        energy_productions = self.energy_productions.filter(energy_type__name__isnull=False)
        if energy_productions:
            return (
                set(
                    energy_productions
                    .values_list("energy_type__name", flat=True)
                    .distinct()
                )
                if self.visible
                else None
            )
        return None

    class Meta(Model.Meta):
        ordering = ["pk"]
        permission_classes = [InheritPermissions | EPRegionalAdminPermission]
        inherit_permissions = ["citizen_project"]
        rdf_type = "energiepartagee:production_site"
        nested_fields = [
            "citizen_project",
            "partner_links",
            "energy_productions",
            "earned_distinctions",
        ]
        serializer_fields = [
            "name",
            "visible",
            "technology_used",
            "energy_type",
            "description",
            "reference_unit",
            "progress_status",
            "energies_produced",
            "total_development_budget",
            "total_investment_budget",
            "yearly_turnover",
            "address",
            "postcode",
            "city",
            "department",
            "region",
            "lat",
            "lng",
            "expected_commissionning_year",
            "effective_commissionning_year",
            "picture",
            "investment_capacity_ratio",
            "grants_earned_amount",
            "production_tracking_url",
            "partner_links",
            "energy_productions",
            "earned_distinctions",
            "citizen_project",
        ]
        verbose_name = _("Site de production")
        verbose_name_plural = _("Sites de productions")
        depth = 0

    def __str__(self):
        if self.name:
            return self.name
        else:
            return self.urlid
